AppBreakpointsManager class

Constructors

AppBreakpointsManager({required Size size, required BuildContext context})
const

Properties

contentInsets double
no setter
contentPadding EdgeInsets
no setter
contentVerticalInsets double
no setter
contentWidth double
no setter
context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final
width double
no setter

Methods

from(EBreakpoints breakpoint) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
since(EBreakpoints breakpoint) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited