AppIcons class

Constructors

AppIcons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

angles_up_down → const String
arrow_angle_down → const String
arrow_angle_left → const String
arrows_from_line → const String
arrows_to_line → const String
atom → const String
atom_simple → const String
bell → const String
bolt → const String
book → const String
bookmark → const String
box_archive → const String
box_check → const String
box_open → const String
broom_wide → const String
cart_circle_plus → const String
check → const String
circle → const String
circle_check → const String
circle_exclamation → const String
circle_play → const String
circle_plus → const String
circle_user → const String
compass → const String
cook → const String
edit_sqaure → const String
eye_dropper → const String
filter → const String
fire → const String
folder → const String
food_apple → const String
food_avocado → const String
food_banana → const String
food_blueberries → const String
food_bread → const String
food_broccoli → const String
food_burger → const String
food_butter → const String
food_carrot → const String
food_cheese → const String
food_cherries → const String
food_chestnut → const String
food_citrus → const String
food_citrus_slice → const String
food_cocount → const String
food_corn → const String
food_crab → const String
food_crate_empty → const String
food_cucumber → const String
food_egg → const String
food_eggplant → const String
food_fish → const String
food_fish_boned → const String
food_fish_cooked → const String
food_flour → const String
food_garlic → const String
food_glass → const String
food_grapes → const String
food_kiwi → const String
food_leaf → const String
food_leafy → const String
food_leafy_green → const String
food_lemon → const String
food_lobster → const String
food_mango → const String
food_meat → const String
food_melon → const String
food_melon_slice → const String
food_mushroom → const String
food_olive → const String
food_olive_branch → const String
food_onion → const String
food_peach → const String
food_peanut → const String
food_peanuts → const String
food_peapod → const String
food_pear → const String
food_pepper → const String
food_pepper_hot → const String
food_pineapple → const String
food_pizza_slice → const String
food_potato → const String
food_pumpkin → const String
food_salad → const String
food_salt → const String
food_seedling → const String
food_shrimp → const String
food_spaghetti → const String
food_squid → const String
food_steak → const String
food_strawberry → const String
food_tomato → const String
food_vegetable_oil → const String
food_watermelon_slice → const String
food_wheat → const String
food_wheat_awn → const String
food_wine_bottle → const String
fork_knife → const String
gauge → const String
grid → const String
image → const String
location → const String
plus → const String
quote_left → const String
radar → const String
rotate → const String
route → const String
sets → const AppIconsSets
settings → const String
share → const String
square_check → const String
square_quote → const String
square_xmark → const String
star → const String
star_half → const String
thumbs_down → const String
thumbs_up → const String
timer → const String
trash → const String
trash_list → const String