BaseEmptyAction class

Constructors

BaseEmptyAction({required String text, Color? color, bool isInverted = false, VoidCallback? onPressed})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
isInverted bool
final
onPressed VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited