BaseButtonText class

Inheritance

Constructors

BaseButtonText({Key? key, required String text, double textFontSize = 16, Color? textColor, Color? hoverTextColor, Color? activeTextColor, String? icon, double iconSize = 18, bool isLoading = false, bool isActive = false, Widget? child, Widget builder({Color backgroundColor, Animation? borderAnimation, bool isHovering, Animation? textAnimation, Color textColor, AnimationController textController})?, void onPressed()?})
const

Properties

activeTextColor Color?
final
builder Widget Function({Color backgroundColor, Animation? borderAnimation, bool isHovering, Animation? textAnimation, Color textColor, AnimationController textController})?
final
child Widget?
final
hashCode int
The hash code for this object.
no setterinherited
hoverTextColor Color?
final
icon String?
final
iconSize double
final
isActive bool
final
isLoading bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
textColor Color?
final
textFontSize double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited