BaseFieldInput class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BaseFieldInput
Constructors
-
BaseFieldInput({Key? key, String? label, String? initialValue = '', double fontSize = 18, TextAlign textAlign = TextAlign.start, FontWeight fontWeight = FontWeight.bold, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 12), String placeholder = 'Type a text', double? placeholderFontSize = 18, MainAxisAlignment placeholderTextAlign = MainAxisAlignment.start, FontWeight placeholderFontWeight = FontWeight.bold, EdgeInsets placeholderPadding = EdgeInsets.zero, double? width, double height = 40, Border? border, BorderRadiusGeometry? borderRadius, Color? background, Widget leading = const SizedBox(), Widget trailing = const SizedBox(), bool? isError, bool obscureText = false, TextInputType? keyboardType, Iterable<
String> ? autofillHints, TextEditingController? controller, String? validator(String?)?, void onChanged(String?)?}) -
const
Properties
-
autofillHints
→ Iterable<
String> ? -
final
- background → Color?
-
final
- border → Border?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- controller → TextEditingController?
-
final
- fontSize → double
-
final
- fontWeight → FontWeight
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- initialValue → String?
-
final
- isError → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- label → String?
-
final
- leading → Widget
-
final
- obscureText → bool
-
final
- onChanged → void Function(String?)?
-
final
- padding → EdgeInsetsGeometry
-
final
- placeholder → String
-
final
- placeholderFontSize → double?
-
final
- placeholderFontWeight → FontWeight
-
final
- placeholderPadding → EdgeInsets
-
final
- placeholderTextAlign → MainAxisAlignment
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textAlign → TextAlign
-
final
- trailing → Widget
-
final
- validator → String? Function(String?)?
-
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited