BaseFieldSelectMulti class

Inheritance

Constructors

BaseFieldSelectMulti({Key? key, String? label, List<Option> selected = const [], double fontSize = 18, TextAlign textAlign = TextAlign.start, FontWeight fontWeight = FontWeight.bold, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 12), List<Option> options = const [], String placeholder = 'Select an items', double? placeholderFontSize = 18, MainAxisAlignment placeholderTextAlign = MainAxisAlignment.start, FontWeight placeholderFontWeight = FontWeight.bold, EdgeInsets placeholderPadding = EdgeInsets.zero, double? width, double height = 40, Border? border, BorderRadiusGeometry? borderRadius, Color? background, Widget renderOption(Option option, dynamic onPressed())?, bool? isError, void onChanged(List<Option>)?})
const

Properties

background Color?
final
border Border?
final
borderRadius BorderRadiusGeometry?
final
fontSize double
final
fontWeight FontWeight
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
isError bool?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
onChanged → void Function(List<Option>)?
final
options List<Option>
final
padding EdgeInsetsGeometry
final
placeholder String
final
placeholderFontSize double?
final
placeholderFontWeight FontWeight
final
placeholderPadding EdgeInsets
final
placeholderTextAlign MainAxisAlignment
final
renderOption Widget Function(Option option, dynamic onPressed())?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected List<Option>
final
textAlign TextAlign
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited