AppUtils class
Constructors
- AppUtils()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
chunk<
T> (List< T> arr, int size) → List<List< T> > -
degreeToRadian(
double degree) → double -
getPrettyJSONString(
dynamic jsonObject) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
radianToDegree(
double radian) → double -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited